@@ -75,7 +75,7 @@ public Q_SLOTS:
     void desktopResized();
 
 protected:
-    virtual bool eventFilter(QObject *obj, QEvent *event);
+    bool eventFilter(QObject *obj, QEvent *event) Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
     void resetRequestIgnore();
